@@ -17,6 +17,8 @@ from keystoneauth1 import loading
 from keystoneauth1 import session as ksa_session
 
 from zunclient.common import httpclient
+from zunclient.v1 import actions
+from zunclient.v1 import availability_zones as az
 from zunclient.v1 import capsules
 from zunclient.v1 import containers
 from zunclient.v1 import hosts
@@ -35,7 +37,7 @@ class Client(object):
                  project_id=None, project_name=None, region_name=None,
                  service_name=None, service_type='container', session=None,
                  user_domain_id=None, user_domain_name=None,
-                 username=None, **kwargs):
+                 username=None, cacert=None, **kwargs):
         """Initialization of Client object.
 
         :param api_version: Container API version
@@ -58,6 +60,7 @@ class Client(object):
         :param str user_domain_id: ID of user domain
         :param str user_id: User ID
         :param str username: Username
+        :param str cacert: CA certificate
         """
         if endpoint_override and auth_token:
             auth_type = 'admin_token'
@@ -97,7 +100,7 @@ class Client(object):
             # This should be able to handle v2 and v3 Keystone Auth
             auth_plugin = loader.load_from_options(**loader_kwargs)
             session = ksa_session.Session(auth=auth_plugin,
-                                          verify=(not insecure))
+                                          verify=(cacert or not insecure))
         client_kwargs = {}
         if not endpoint_override:
             try:
@@ -127,6 +130,8 @@ class Client(object):
         self.hosts = hosts.HostManager(self.http_client)
         self.versions = versions.VersionManager(self.http_client)
         self.capsules = capsules.CapsuleManager(self.http_client)
+        self.availability_zones = az.AvailabilityZoneManager(self.http_client)
+        self.actions = actions.ActionManager(self.http_client)
 
     @property
     def api_version(self):
